@@ -5,6 +5,7 @@
 (autoload 'custom-add-loads "cus-load")
 
 (put 'mime-display 'custom-loads '("mm-decode"))
+(put 'spam-stat 'custom-loads '("spam-stat"))
 (put 'bbdb-mua-specific-gnus 'custom-loads '("gnus-bbdb"))
 (put 'nnmail 'custom-loads '("nnmail"))
 (put 'gnus-fun 'custom-loads '("gnus-fun"))
@@ -35,11 +36,13 @@
 (put 'gnus-summary-pick 'custom-loads '("gnus-salt"))
 (put 'gnus-thread 'custom-loads '("gnus-sum"))
 (put 'languages 'custom-loads '("sieve"))
+(put 'spam 'custom-loads '("spam"))
 (put 'nnmail-various 'custom-loads '("nnmail"))
-(put 'message-various 'custom-loads '("message-utils" "message"))
+(put 'message-various 'custom-loads '("message"))
 (put 'gnus-summary-exit 'custom-loads '("gnus-sum" "gnus"))
 (put 'news 'custom-loads '("gnus-offline" "gnus" "message" "mm-decode"))
-(put 'gnus 'custom-loads '("gnus-art" "gnus-async" "gnus-delay" "gnus-demon" "gnus-dup" "gnus-eform" "gnus-namazu" "gnus-offline" "gnus-sieve" "gnus-undo" "gnus-uu" "gnus-win" "gnus-xmas" "gnus" "mail-source" "mm-url" "nnimap" "nnmail" "nnshimbun" "rfc1843"))
+(put 'gnus 'custom-loads '("gnus-art" "gnus-async" "gnus-delay" "gnus-demon" "gnus-dup" "gnus-eform" "gnus-namazu" "gnus-offline" "gnus-sieve" "gnus-undo" "gnus-uu" "gnus-win" "gnus-xmas" "gnus" "mail-source" "mm-url" "nnimap" "nnmail" "nnshimbun" "spam-stat"))
+(put 'spam-bogofilter 'custom-loads '("spam"))
 (put 'gnus-server 'custom-loads '("gnus-srvr" "gnus" "nnheader"))
 (put 'multimedia 'custom-loads '("gnus-audio" "mm-decode"))
 (put 'gnus-summary-visual 'custom-loads '("gnus-sum" "gnus"))
@@ -60,7 +63,7 @@
 (put 'gnus-score-default 'custom-loads '("gnus-score" "gnus-sum"))
 (put 'nnmail-duplicate 'custom-loads '("nnmail"))
 (put 'gnus-format 'custom-loads '("gnus-spec"))
-(put 'mime 'custom-loads '("gnus-mailcap" "mm-bodies" "mm-encode" "mm-util"))
+(put 'mime 'custom-loads '("gnus-mailcap" "mm-bodies" "mm-encode" "mm-util" "rfc1843"))
 (put 'gnus-delay 'custom-loads '("gnus-delay"))
 (put 'message-interface 'custom-loads '("message"))
 (put 'nnmail-files 'custom-loads '("nnmail"))
@@ -76,7 +79,7 @@
 (put 'message-forwarding 'custom-loads '("message"))
 (put 'message-faces 'custom-loads '("message"))
 (put 'gnus-article-treat 'custom-loads '("gnus-art"))
-(put 'gnus-charset 'custom-loads '("gnus-group" "gnus-msg" "gnus-sum"))
+(put 'gnus-charset 'custom-loads '("gnus-group" "gnus-sum" "gnus"))
 (put 'gnus-article-mime 'custom-loads '("gnus-art" "gnus-sum" "mm-uu"))
 (put 'nnmail-retrieve 'custom-loads '("nnmail"))
 (put 'gnus-duplicate 'custom-loads '("gnus-dup"))
@@ -196,6 +199,8 @@
 (custom-put-if-not 'gnus-use-byte-compile 'standard-value t)
 (custom-put-if-not 'gnus-ignored-from-addresses 'custom-version "21.1")
 (custom-put-if-not 'gnus-ignored-from-addresses 'standard-value t)
+(custom-put-if-not 'gnus-inhibit-mime-unbuttonizing 'custom-version "21.3")
+(custom-put-if-not 'gnus-inhibit-mime-unbuttonizing 'standard-value t)
 (custom-put-if-not 'gnus-group-name-charset-method-alist 'custom-version "21.1")
 (custom-put-if-not 'gnus-group-name-charset-method-alist 'standard-value t)
 (custom-put-if-not 'starttls 'custom-version "21.1")
@@ -242,6 +247,8 @@
 (custom-put-if-not 'imap 'group-documentation "Low-level IMAP issues.")
 (custom-put-if-not 'message-forward-ignored-headers 'custom-version "21.1")
 (custom-put-if-not 'message-forward-ignored-headers 'standard-value t)
+(custom-put-if-not 'gnus-agent-consider-all-articles 'custom-version "21.4")
+(custom-put-if-not 'gnus-agent-consider-all-articles 'standard-value t)
 (custom-put-if-not 'nnmail-scan-directory-mail-source-once 'custom-version "21.1")
 (custom-put-if-not 'nnmail-scan-directory-mail-source-once 'standard-value t)
 (custom-put-if-not 'gnus-preserve-marks 'custom-version "21.1")
@@ -277,8 +284,8 @@
 
 
 ;;;### (autoloads (binhex-decode-region binhex-decode-region-external
-;;;;;;  binhex-decode-region-internal) "binhex" "binhex.el" (15575
-;;;;;;  16891))
+;;;;;;  binhex-decode-region-internal) "binhex" "binhex.el" (15895
+;;;;;;  52374))
 ;;; Generated autoloads from binhex.el
 
 (defconst binhex-begin-line "^:...............................................................$")
@@ -314,7 +321,7 @@ nil instead of to signal an error by setting the option
 ;;;### (autoloads (gnus-article-outlook-deuglify-article gnus-outlook-deuglify-article
 ;;;;;;  gnus-outlook-repair-attribution gnus-outlook-unwrap-lines
 ;;;;;;  gnus-outlook-deuglify-unwrap-max gnus-outlook-deuglify-unwrap-min)
-;;;;;;  "deuglify" "deuglify.el" (15575 16891))
+;;;;;;  "deuglify" "deuglify.el" (15895 52374))
 ;;; Generated autoloads from deuglify.el
 
 (defvar gnus-outlook-deuglify-unwrap-min 45 "\
@@ -324,8 +331,8 @@ Minimum length of the cited line above the (possibly) wrapped line.")
 Maximum length of the cited line after unwrapping.")
 
 (autoload (quote gnus-outlook-unwrap-lines) "deuglify" "\
-Unwrap lines that appear to be wrapped citation lines.  You can
-control what lines will be unwrapped by frobbing
+Unwrap lines that appear to be wrapped citation lines.
+You can control what lines will be unwrapped by frobbing
 `gnus-outlook-deuglify-unwrap-min' and
 `gnus-outlook-deuglify-unwrap-max', indicating the miminum and maximum
 length of an unwrapped citation line." t nil)
@@ -351,7 +358,7 @@ Play sounds in message buffers." t nil)
 ;;;***
 
 ;;;### (autoloads (gnus gnus-other-frame gnus-slave gnus-no-server
-;;;;;;  gnus-slave-no-server) "gnus" "gnus.el" (15695 54013))
+;;;;;;  gnus-slave-no-server) "gnus" "gnus.el" (15895 52379))
 ;;; Generated autoloads from gnus.el
 
 (autoload (quote gnus-slave-no-server) "gnus" "\
@@ -370,7 +377,14 @@ server." t nil)
 Read news as a slave." t nil)
 
 (autoload (quote gnus-other-frame) "gnus" "\
-Pop up a frame to read news." t nil)
+Pop up a frame to read news.
+This will call one of the Gnus commands which is specified by the user
+option `gnus-other-frame-function' (default `gnus') with the argument
+ARG if Gnus is not running, otherwise just pop up a Gnus frame.  The
+optional second argument DISPLAY should be a standard display string
+such as \"unix:0\" to specify where to pop up a frame.  If DISPLAY is
+omitted or the function `make-frame-on-display' is not available, the
+current display is used." t nil)
 
 (autoload (quote gnus) "gnus" "\
 Read network news.
@@ -381,8 +395,9 @@ prompt the user for the name of an NNTP server to use." t nil)
 ;;;***
 
 ;;;### (autoloads (gnus-agent-regenerate gnus-agent-batch gnus-agent-batch-fetch
-;;;;;;  gnus-agentize gnus-slave-unplugged gnus-plugged gnus-unplugged)
-;;;;;;  "gnus-agent" "gnus-agent.el" (15695 54011))
+;;;;;;  gnus-agent-possibly-save-gcc gnus-agentize gnus-slave-unplugged
+;;;;;;  gnus-plugged gnus-unplugged) "gnus-agent" "gnus-agent.el"
+;;;;;;  (15895 52374))
 ;;; Generated autoloads from gnus-agent.el
 
 (autoload (quote gnus-unplugged) "gnus-agent" "\
@@ -405,19 +420,23 @@ This will modify the `gnus-setup-news-hook', and
 `message-send-mail-real-function' variables, and install the Gnus agent
 minor mode in all Gnus buffers." t nil)
 
+(autoload (quote gnus-agent-possibly-save-gcc) "gnus-agent" "\
+Save GCC if Gnus is unplugged." nil nil)
+
 (autoload (quote gnus-agent-batch-fetch) "gnus-agent" "\
 Start Gnus and fetch session." t nil)
 
-(autoload (quote gnus-agent-batch) "gnus-agent" nil t nil)
+(autoload (quote gnus-agent-batch) "gnus-agent" "\
+Start Gnus, send queue and fetch session." t nil)
 
 (autoload (quote gnus-agent-regenerate) "gnus-agent" "\
 Regenerate all agent covered files.
-If CLEAN, don't read existing active and agentview files." t nil)
+If CLEAN, don't read existing active files." t nil)
 
 ;;;***
 
 ;;;### (autoloads (gnus-article-prepare-display) "gnus-art" "gnus-art.el"
-;;;;;;  (15695 54011))
+;;;;;;  (15895 52375))
 ;;; Generated autoloads from gnus-art.el
 
 (autoload (quote gnus-article-prepare-display) "gnus-art" "\
@@ -492,7 +511,7 @@ Call this function to hook BBDB into message-mode." nil nil)
 ;;;***
 
 ;;;### (autoloads (gnus-cache-generate-nov-databases gnus-cache-generate-active
-;;;;;;  gnus-jog-cache) "gnus-cache" "gnus-cache.el" (15695 54011))
+;;;;;;  gnus-jog-cache) "gnus-cache" "gnus-cache.el" (15895 52375))
 ;;; Generated autoloads from gnus-cache.el
 
 (autoload (quote gnus-jog-cache) "gnus-cache" "\
@@ -569,7 +588,7 @@ Convenience method to turn on gnus-dired-mode." nil nil)
 ;;;***
 
 ;;;### (autoloads (gnus-draft-reminder) "gnus-draft" "gnus-draft.el"
-;;;;;;  (15575 16892))
+;;;;;;  (15895 52375))
 ;;; Generated autoloads from gnus-draft.el
 
 (autoload (quote gnus-draft-reminder) "gnus-draft" "\
@@ -596,7 +615,7 @@ Convert the X-Faces in region to a PPM file." t nil)
 ;;;***
 
 ;;;### (autoloads (gnus-fetch-group-other-frame gnus-fetch-group)
-;;;;;;  "gnus-group" "gnus-group.el" (15695 54011))
+;;;;;;  "gnus-group" "gnus-group.el" (15895 52376))
 ;;; Generated autoloads from gnus-group.el
 
 (autoload (quote gnus-fetch-group) "gnus-group" "\
@@ -639,8 +658,8 @@ Minor mode for providing mailing-list commands.
 ;;;***
 
 ;;;### (autoloads (gnus-group-split-fancy gnus-group-split gnus-group-split-update
-;;;;;;  gnus-group-split-setup) "gnus-mlspl" "gnus-mlspl.el" (15418
-;;;;;;  33142))
+;;;;;;  gnus-group-split-setup) "gnus-mlspl" "gnus-mlspl.el" (15895
+;;;;;;  52376))
 ;;; Generated autoloads from gnus-mlspl.el
 
 (autoload (quote gnus-group-split-setup) "gnus-mlspl" "\
@@ -663,7 +682,7 @@ unless overridden by any group marked as a catch-all group.  Typical
 uses are as simple as the name of a default mail group, but more
 elaborate fancy splits may also be useful to split mail that doesn't
 match any of the group-specified splitting rules.  See
-gnus-group-split-fancy for details." t nil)
+`gnus-group-split-fancy' for details." t nil)
 
 (autoload (quote gnus-group-split-update) "gnus-mlspl" "\
 Computes nnmail-split-fancy from group params and CATCH-ALL, by
@@ -674,7 +693,7 @@ instead.  This variable is set by gnus-group-split-setup." t nil)
 
 (autoload (quote gnus-group-split) "gnus-mlspl" "\
 Uses information from group parameters in order to split mail.
-See gnus-group-split-fancy for more information.
+See `gnus-group-split-fancy' for more information.
 
 gnus-group-split is a valid value for nnmail-split-methods." nil nil)
 
@@ -685,10 +704,10 @@ It can be embedded into `nnmail-split-fancy' lists with the SPLIT
 \(: gnus-group-split-fancy GROUPS NO-CROSSPOST CATCH-ALL)
 
 GROUPS may be a regular expression or a list of group names, that will
-be used to select candidate groups.  If it is ommited or nil, all
+be used to select candidate groups.  If it is omitted or nil, all
 existing groups are considered.
 
-if NO-CROSSPOST is ommitted or nil, a & split will be returned,
+if NO-CROSSPOST is omitted or nil, a & split will be returned,
 otherwise, a | split, that does not allow crossposting, will be
 returned.
 
@@ -721,7 +740,7 @@ nnml:mail.foo:
 nnml:mail.others:
 \((split-spec . catch-all))
 
-Calling (gnus-group-split-fancy nil nil \"mail.misc\") returns:
+Calling (gnus-group-split-fancy nil nil \"mail.others\") returns:
 
 \(| (& (any \"\\\\(bar@femail\\\\.com\\\\|.*@femail\\\\.com\\\\)\"
 	   \"mail.bar\")
@@ -742,7 +761,7 @@ Update the .newsrc.eld file to reflect the change of nntp server." t nil)
 ;;;***
 
 ;;;### (autoloads (gnus-button-reply gnus-button-mailto gnus-msg-mail)
-;;;;;;  "gnus-msg" "gnus-msg.el" (15736 24360))
+;;;;;;  "gnus-msg" "gnus-msg.el" (15895 52376))
 ;;; Generated autoloads from gnus-msg.el
 
 (autoload (quote gnus-msg-mail) "gnus-msg" "\
@@ -762,8 +781,8 @@ Like `message-reply'." t nil)
 
 ;;;### (autoloads (gnus-namazu-insinuate gnus-namazu-stop-update
 ;;;;;;  gnus-namazu-update-all-indices gnus-namazu-update-index gnus-namazu-create-index
-;;;;;;  gnus-namazu-search) "gnus-namazu" "gnus-namazu.el" (15695
-;;;;;;  54012))
+;;;;;;  gnus-namazu-search) "gnus-namazu" "gnus-namazu.el" (15895
+;;;;;;  52376))
 ;;; Generated autoloads from gnus-namazu.el
 
 (autoload (quote gnus-namazu-search) "gnus-namazu" "\
@@ -808,7 +827,7 @@ If picons are already displayed, remove them." t nil)
 ;;;### (autoloads (gnus-add-to-sorted-list gnus-sorted-nunion gnus-sorted-union
 ;;;;;;  gnus-sorted-nintersection gnus-sorted-intersection gnus-intersection
 ;;;;;;  gnus-sorted-complement gnus-sorted-ndifference gnus-sorted-difference)
-;;;;;;  "gnus-range" "gnus-range.el" (15575 16893))
+;;;;;;  "gnus-range" "gnus-range.el" (15895 52376))
 ;;; Generated autoloads from gnus-range.el
 
 (autoload (quote gnus-sorted-difference) "gnus-range" "\
@@ -872,7 +891,7 @@ See the documentation for these variables and functions for details." t nil)
 ;;;***
 
 ;;;### (autoloads (gnus-batch-brew-soup) "gnus-soup" "gnus-soup.el"
-;;;;;;  (15575 16894))
+;;;;;;  (15895 52376))
 ;;; Generated autoloads from gnus-soup.el
 
 (autoload (quote gnus-batch-brew-soup) "gnus-soup" "\
@@ -890,7 +909,7 @@ Note -- this function hasn't been implemented yet." t nil)
 ;;;***
 
 ;;;### (autoloads (gnus-update-format) "gnus-spec" "gnus-spec.el"
-;;;;;;  (15435 43749))
+;;;;;;  (15895 52376))
 ;;; Generated autoloads from gnus-spec.el
 
 (autoload (quote gnus-update-format) "gnus-spec" "\
@@ -898,8 +917,9 @@ Update the format specification near point." t nil)
 
 ;;;***
 
-;;;### (autoloads (gnus-declare-backend gnus-unload) "gnus-start"
-;;;;;;  "gnus-start.el" (15695 54012))
+;;;### (autoloads (gnus-fixup-nnimap-unread-after-getting-new-news
+;;;;;;  gnus-declare-backend gnus-unload) "gnus-start" "gnus-start.el"
+;;;;;;  (15895 52376))
 ;;; Generated autoloads from gnus-start.el
 
 (autoload (quote gnus-unload) "gnus-start" "\
@@ -911,10 +931,12 @@ cautiously -- unloading may cause trouble." t nil)
 (autoload (quote gnus-declare-backend) "gnus-start" "\
 Declare backend NAME with ABILITIES as a Gnus backend." nil nil)
 
+(autoload (quote gnus-fixup-nnimap-unread-after-getting-new-news) "gnus-start" nil nil nil)
+
 ;;;***
 
 ;;;### (autoloads (gnus-add-configuration) "gnus-win" "gnus-win.el"
-;;;;;;  (15575 16895))
+;;;;;;  (15895 52379))
 ;;; Generated autoloads from gnus-win.el
 
 (autoload (quote gnus-add-configuration) "gnus-win" "\
@@ -935,14 +957,53 @@ Convert HTML to plain text in the current buffer." t nil)
 ;;;;;;  message-bounce message-resend message-insinuate-rmail message-forward-rmail-make-body
 ;;;;;;  message-forward-make-body message-forward message-recover
 ;;;;;;  message-supersede message-cancel-news message-followup message-wide-reply
-;;;;;;  message-reply message-news message-mail message-mode message-signature-file
+;;;;;;  message-reply message-news message-mail message-mode message-reduce-to-to-cc
+;;;;;;  message-cross-post-followup-to message-cross-post-insert-note
+;;;;;;  message-cross-post-followup-to-header message-add-archive-header
+;;;;;;  message-mark-insert-file message-mark-inserted-region message-change-subject
+;;;;;;  message-signature-insert-empty-line message-signature-file
 ;;;;;;  message-signature message-indent-citation-function message-suspend-font-lock-when-citing
 ;;;;;;  message-cite-function message-yank-prefix message-citation-line-function
 ;;;;;;  message-send-mail-function message-user-organization-file
-;;;;;;  message-signature-separator message-from-style) "message"
-;;;;;;  "message.el" (15695 54013))
+;;;;;;  message-signature-separator message-from-style message-cross-post-note-function
+;;;;;;  message-followup-to-note message-cross-post-note message-cross-post-default
+;;;;;;  message-archive-note message-archive-header message-mark-insert-end
+;;;;;;  message-mark-insert-begin) "message" "message.el" (15895
+;;;;;;  52380))
 ;;; Generated autoloads from message.el
 
+(defvar message-mark-insert-begin "--8<---------------cut here---------------start------------->8---\n" "\
+How to mark the beginning of some inserted text.")
+
+(defvar message-mark-insert-end "--8<---------------cut here---------------end--------------->8---\n" "\
+How to mark the end of some inserted text.")
+
+(defvar message-archive-header "X-No-Archive: Yes\n" "\
+Header to insert when you don't want your article to be archived.
+Archives (such as groups.googgle.com) respect this header.")
+
+(defvar message-archive-note "X-No-Archive: Yes - save http://groups.google.com/" "\
+Note to insert why you wouldn't want this posting archived.
+If nil, don't insert any text in the body.")
+
+(defvar message-cross-post-default t "\
+When non-nil `message-cross-post-followup-to' will normally perform a
+crosspost.  If nil, `message-cross-post-followup-to' will only do a followup.
+Note that you can explicitly override this setting by calling
+`message-cross-post-followup-to' with a prefix.")
+
+(defvar message-cross-post-note "Crosspost & Followup-To: " "\
+Note to insert before signature to notify of xpost and follow-up.")
+
+(defvar message-followup-to-note "Followup-To: " "\
+Note to insert before signature to notify of follow-up only.")
+
+(defvar message-cross-post-note-function (quote message-cross-post-insert-note) "\
+Function to use to insert note about Crosspost or Followup-To.
+The function will be called with four arguments.  The function should not only
+insert a note, but also ensure old notes are deleted.  See the documentation
+for `message-cross-post-insert-note'. ")
+
 (defvar message-from-style (quote default) "\
 *Specifies how \"From\" headers look.
 
@@ -969,7 +1030,8 @@ variable `mail-header-separator'.
 
 Valid values include `message-send-mail-with-sendmail' (the default),
 `message-send-mail-with-mh', `message-send-mail-with-qmail',
-`message-send-mail-with-smtp', `smtpmail-send-it' and `feedmail-send-it'.
+`message-send-mail-with-smtp', `message-smtpmail-send-it',
+`smtpmail-send-it' and `feedmail-send-it'.
 
 See also `send-mail-function'.")
 
@@ -1017,8 +1079,47 @@ If a form, the result from the form will be used instead.")
 Ignored if the named file doesn't exist.
 If nil, don't insert a signature.")
 
+(defvar message-signature-insert-empty-line t "\
+*If non-nil, insert an empty line before the signature separator.")
+
 (define-mail-user-agent (quote message-user-agent) (quote message-mail) (quote message-send-and-exit) (quote message-kill-buffer) (quote message-send-hook))
 
+(autoload (quote message-change-subject) "message" "\
+Ask for new Subject: header, append (was: <Old Subject>)." t nil)
+
+(autoload (quote message-mark-inserted-region) "message" "\
+Mark some region in the current article with enclosing tags.
+See `message-mark-insert-begin' and `message-mark-insert-end'." t nil)
+
+(autoload (quote message-mark-insert-file) "message" "\
+Inserts FILE at point, marking it with enclosing tags.
+See `message-mark-insert-begin' and `message-mark-insert-end'." t nil)
+
+(autoload (quote message-add-archive-header) "message" "\
+Insert \"X-No-Archive: Yes\" in the header and a note in the body.
+The note can be customized using `message-archive-note'.  When called with a
+prefix argument, ask for a text to insert.  If you don't want the note in the
+body, set  `message-archive-note' to nil." t nil)
+
+(autoload (quote message-cross-post-followup-to-header) "message" "\
+Mangles FollowUp-To and Newsgroups header to point to TARGET-GROUP.
+With prefix-argument just set Follow-Up, don't cross-post." t nil)
+
+(autoload (quote message-cross-post-insert-note) "message" "\
+Insert a in message body note about a set Followup or Crosspost.
+If there have been previous notes, delete them.  TARGET-GROUP specifies the
+group to Followup-To.  When CROSS-POST is t, insert note about
+crossposting.  IN-OLD specifies whether TARGET-GROUP is a member of
+OLD-GROUPS.  OLD-GROUPS lists the old-groups the posting would have
+been made to before the user asked for a Crosspost." nil nil)
+
+(autoload (quote message-cross-post-followup-to) "message" "\
+Crossposts message and sets Followup-To to TARGET-GROUP.
+With prefix-argument just set Follow-Up, don't cross-post." t nil)
+
+(autoload (quote message-reduce-to-to-cc) "message" "\
+Replace contents of To: header with contents of Cc: or Bcc: header." t nil)
+
 (autoload (quote message-mode) "message" "\
 Major mode for editing mail and news to be sent.
 Like Text Mode but with these additional commands:\\<message-mode-map>
@@ -1033,8 +1134,12 @@ C-c C-f  move to a header field (and create it if there isn't):
          C-c C-f C-o  move to From (\"Originator\")
 	 C-c C-f C-f  move to Followup-To
 	 C-c C-f C-m  move to Mail-Followup-To
-	 C-c C-f C-i  cycle through Importance values
 	 C-c C-f c    move to Mail-Copies-To
+	 C-c C-f C-i  cycle through Importance values
+	 C-c C-f s    change subject and append \"(was: <Old Subject>)\"
+	 C-c C-f x    crossposting with FollowUp-To header and note in body
+	 C-c C-f t    replace To: header with contents of Cc: or Bcc:
+	 C-c C-f a    Insert X-No-Archive: header and a note in the body
 C-c C-t  `message-insert-to' (add a To header to a news followup)
 C-c C-l  `message-to-list-only' (removes all but list address in to/cc)
 C-c C-n  `message-insert-newsgroups' (add a Newsgroup header to a news reply)
@@ -1049,6 +1154,8 @@ C-c C-z  `message-kill-to-signature' (kill the text up to the signature).
 C-c C-r  `message-caesar-buffer-body' (rot13 the message body).
 C-c C-u  `message-insert-or-toggle-importance'  (insert or cycle importance).
 C-c M-n  `message-insert-disposition-notification-to'  (request receipt).
+C-c M-m  `message-mark-inserted-region' (mark region with enclosing tags).
+C-c M-f  `message-mark-insert-file' (insert file marked with enclosing tags).
 M-RET    `message-newline-and-reformat' (break the line and reformat)." t nil)
 
 (autoload (quote message-mail) "message" "\
@@ -1123,31 +1230,6 @@ Remove all boldness (overstruck characters) in the region.
 Called from program, takes two arguments START and END
 which specify the range to operate on." t nil)
 
-;;;***
-
-;;;### (autoloads (message-xpost-fup2 message-change-subject message-strip-subject-was
-;;;;;;  message-mark-insert-file message-mark-inserted-region) "message-utils"
-;;;;;;  "message-utils.el" (15575 16896))
-;;; Generated autoloads from message-utils.el
-
-(autoload (quote message-mark-inserted-region) "message-utils" "\
-Mark some region in the current article with enclosing tags.
-See `message-begin-inserted-text-mark' and `message-end-inserted-text-mark'." t nil)
-
-(autoload (quote message-mark-insert-file) "message-utils" "\
-Inserts FILE at point, marking it with enclosing tags.
-See `message-begin-inserted-text-mark' and `message-end-inserted-text-mark'." t nil)
-
-(autoload (quote message-strip-subject-was) "message-utils" "\
-Remove trailing \"(Was: <old subject>)\" from subject lines." nil nil)
-
-(autoload (quote message-change-subject) "message-utils" "\
-Ask for new Subject: header, append (was: <Old Subject>)." t nil)
-
-(autoload (quote message-xpost-fup2) "message-utils" "\
-Crossposts message and sets Followup-To to TARGET-GROUP.
-With prefix-argument just set Follow-Up, don't cross-post." t nil)
-
 ;;;***
 
 ;;;### (autoloads (mm-inline-external-body) "mm-extern" "mm-extern.el"
@@ -1174,7 +1256,7 @@ If NO-DISPLAY is nil, display it. Otherwise, do nothing after replacing." nil ni
 
 ;;;***
 
-;;;### (autoloads (mm-uu-dissect) "mm-uu" "mm-uu.el" (15575 16898))
+;;;### (autoloads (mm-uu-dissect) "mm-uu" "mm-uu.el" (15895 52382))
 ;;; Generated autoloads from mm-uu.el
 
 (autoload (quote mm-uu-dissect) "mm-uu" "\
@@ -1183,7 +1265,7 @@ Dissect the current buffer and return a list of uu handles." nil nil)
 ;;;***
 
 ;;;### (autoloads (mml1991-sign mml1991-encrypt) "mml1991" "mml1991.el"
-;;;;;;  (15695 54015))
+;;;;;;  (15895 52383))
 ;;; Generated autoloads from mml1991.el
 
 (autoload (quote mml1991-encrypt) "mml1991" nil nil nil)
@@ -1194,7 +1276,7 @@ Dissect the current buffer and return a list of uu handles." nil nil)
 
 ;;;### (autoloads (mml2015-self-encrypt mml2015-sign mml2015-encrypt
 ;;;;;;  mml2015-verify-test mml2015-verify mml2015-decrypt-test mml2015-decrypt)
-;;;;;;  "mml2015" "mml2015.el" (15695 54015))
+;;;;;;  "mml2015" "mml2015.el" (15895 52383))
 ;;; Generated autoloads from mml2015.el
 
 (autoload (quote mml2015-decrypt) "mml2015" nil nil nil)
@@ -1214,7 +1296,7 @@ Dissect the current buffer and return a list of uu handles." nil nil)
 ;;;***
 
 ;;;### (autoloads (nndiary-generate-nov-databases) "nndiary" "nndiary.el"
-;;;;;;  (15695 54015))
+;;;;;;  (15895 52383))
 ;;; Generated autoloads from nndiary.el
 
 (autoload (quote nndiary-generate-nov-databases) "nndiary" "\
@@ -1235,7 +1317,7 @@ symbol in the alist." nil nil)
 ;;;***
 
 ;;;### (autoloads (nnfolder-generate-active-file) "nnfolder" "nnfolder.el"
-;;;;;;  (15695 54015))
+;;;;;;  (15895 52383))
 ;;; Generated autoloads from nnfolder.el
 
 (autoload (quote nnfolder-generate-active-file) "nnfolder" "\
@@ -1255,7 +1337,7 @@ Finds out what articles are to be part of the nnkiboze groups." t nil)
 ;;;***
 
 ;;;### (autoloads (nnml-generate-nov-databases) "nnml" "nnml.el"
-;;;;;;  (15695 54015))
+;;;;;;  (15895 52391))
 ;;; Generated autoloads from nnml.el
 
 (autoload (quote nnml-generate-nov-databases) "nnml" "\
@@ -1264,7 +1346,7 @@ Generate NOV databases in all nnml directories." t nil)
 ;;;***
 
 ;;;### (autoloads (gnus-group-make-shimbun-group) "nnshimbun" "nnshimbun.el"
-;;;;;;  (15732 40942))
+;;;;;;  (15895 52391))
 ;;; Generated autoloads from nnshimbun.el
 
 (autoload (quote gnus-group-make-shimbun-group) "nnshimbun" "\
@@ -1273,7 +1355,7 @@ Create a nnshimbun group." t nil)
 ;;;***
 
 ;;;### (autoloads (nnsoup-revert-variables nnsoup-set-variables nnsoup-pack-replies)
-;;;;;;  "nnsoup" "nnsoup.el" (15695 54016))
+;;;;;;  "nnsoup" "nnsoup.el" (15895 52391))
 ;;; Generated autoloads from nnsoup.el
 
 (autoload (quote nnsoup-pack-replies) "nnsoup" "\
@@ -1333,7 +1415,7 @@ Turning on Sieve mode runs `sieve-mode-hook'." t nil)
 ;;;### (autoloads (safe-date-to-time time-to-days time-to-day-in-year
 ;;;;;;  date-leap-year-p days-between date-to-day time-add time-subtract
 ;;;;;;  time-since days-to-time time-less-p seconds-to-time date-to-time)
-;;;;;;  "time-date" "time-date.el" (15575 16907))
+;;;;;;  "time-date" "time-date.el" (15895 52392))
 ;;; Generated autoloads from time-date.el
 
 (autoload (quote date-to-time) "time-date" "\
@@ -1404,6 +1486,18 @@ If FILE-NAME is non-nil, save the result to FILE-NAME." t nil)
 Uudecode region between START and END.
 If FILE-NAME is non-nil, save the result to FILE-NAME." nil nil)
 
+;;;***
+
+;;;### (autoloads (yenc-extract-filename yenc-decode-region) "yenc"
+;;;;;;  "yenc.el" (15895 52392))
+;;; Generated autoloads from yenc.el
+
+(autoload (quote yenc-decode-region) "yenc" "\
+Yenc decode region between START and END using an internal decoder." t nil)
+
+(autoload (quote yenc-extract-filename) "yenc" "\
+Extract file name from an yenc header." nil nil)
+
 ;;;***
 
 (provide 'gnus-load)
